@@ -88,7 +88,7 @@ public:
         pluginList = list;
     }
 
-    Q_REQUIRED_RESULT Qt::ItemFlags flags(const QModelIndex &index) const override
+    [[nodiscard]] Qt::ItemFlags flags(const QModelIndex &index) const override
     {
         Qt::ItemFlags flags = QStringListModel::flags(index);
 
@@ -109,7 +109,7 @@ public:
         return flags;
     }
 
-    Q_REQUIRED_RESULT QModelIndex index(int row, int column, const QModelIndex &parent = QModelIndex()) const override
+    [[nodiscard]] QModelIndex index(int row, int column, const QModelIndex &parent = QModelIndex()) const override
     {
         Q_UNUSED(parent)
         if (row < 0 || row >= pluginList.count()) {
@@ -118,7 +118,7 @@ public:
         return createIndex(row, column, pluginList[row]);
     }
 
-    Q_REQUIRED_RESULT QVariant data(const QModelIndex &index, int role = Qt::DisplayRole) const override
+    [[nodiscard]] QVariant data(const QModelIndex &index, int role = Qt::DisplayRole) const override
     {
         if (!index.isValid() || !index.internalPointer()) {
             return {};
@@ -164,7 +164,7 @@ public:
     }
 
 protected:
-    Q_REQUIRED_RESULT bool lessThan(const QModelIndex &left, const QModelIndex &right) const override
+    [[nodiscard]] bool lessThan(const QModelIndex &left, const QModelIndex &right) const override
     {
         auto leftPlugin = static_cast<KontactInterface::Plugin *>(left.internalPointer());
         auto rightPlugin = static_cast<KontactInterface::Plugin *>(right.internalPointer());
@@ -224,7 +224,7 @@ public:
         painter->restore();
     }
 
-    Q_REQUIRED_RESULT QSize sizeHint(const QStyleOptionViewItem &option, const QModelIndex &index) const override
+    [[nodiscard]] QSize sizeHint(const QStyleOptionViewItem &option, const QModelIndex &index) const override
     {
         if (!index.isValid() || !index.internalPointer()) {
             return {};
@@ -414,11 +414,7 @@ void Navigator::dragMoveEvent(QDragMoveEvent *event)
     if (event->proposedAction() == Qt::IgnoreAction) {
         return;
     }
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-    const QModelIndex dropIndex = indexAt(event->pos());
-#else
     const QModelIndex dropIndex = indexAt(event->position().toPoint());
-#endif
 
     if (!dropIndex.isValid() || !(dropIndex.model()->flags(dropIndex) & Qt::ItemIsEnabled)) {
         event->setAccepted(false);
@@ -441,11 +437,7 @@ void Navigator::dropEvent(QDropEvent *event)
         return;
     }
 
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-    const QModelIndex dropIndex = indexAt(event->pos());
-#else
     const QModelIndex dropIndex = indexAt(event->position().toPoint());
-#endif
 
     if (!dropIndex.isValid()) {
         return;
@@ -559,3 +551,5 @@ void IconSidePane::resizeEvent(QResizeEvent *event)
 }
 
 #include "iconsidepane.moc"
+
+#include "moc_iconsidepane.cpp"
