@@ -70,9 +70,33 @@ using namespace Kontact;
 #include <GrantleeTheme/GrantleeTheme>
 #include <GrantleeTheme/GrantleeThemeManager>
 
+#include <PimCommon/NeedUpdateVersionUtils>
+#include <PimCommon/NeedUpdateVersionWidget>
+
+// signal handler for SIGINT & SIGTERM
+#ifdef Q_OS_UNIX
+#include <KSignalHandler>
+#include <signal.h>
+#include <unistd.h>
+#endif
+
 MainWindow::MainWindow()
     : KontactInterface::Core()
 {
+#ifdef Q_OS_UNIX
+    /**
+     * Set up signal handler for SIGINT and SIGTERM
+     */
+    KSignalHandler::self()->watchSignal(SIGINT);
+    KSignalHandler::self()->watchSignal(SIGTERM);
+    connect(KSignalHandler::self(), &KSignalHandler::signalReceived, this, [this](int signal) {
+        if (signal == SIGINT || signal == SIGTERM) {
+            // Intercept console.
+            printf("Shutting down...\n");
+            slotQuit();
+        }
+    });
+#endif
     // Necessary for "cid" support in kmail.
     QWebEngineUrlScheme cidScheme("cid");
     cidScheme.setFlags(QWebEngineUrlScheme::SecureScheme | QWebEngineUrlScheme::ContentSecurityPolicyIgnored | QWebEngineUrlScheme::LocalScheme
@@ -230,6 +254,15 @@ void MainWindow::initWidgets()
     mTopWidget->setLayout(layout);
     setCentralWidget(mTopWidget);
 
+    if (PimCommon::NeedUpdateVersionUtils::checkVersion()) {
+        const auto status = PimCommon::NeedUpdateVersionUtils::obsoleteVersionStatus(KAboutData::applicationData().version(), QDate::currentDate());
+        if (status != PimCommon::NeedUpdateVersionUtils::ObsoleteVersion::NotObsoleteYet) {
+            auto needUpdateVersionWidget = new PimCommon::NeedUpdateVersionWidget(this);
+            layout->addWidget(needUpdateVersionWidget);
+            needUpdateVersionWidget->setObsoleteVersion(status);
+        }
+    }
+
     mSplitter = new QSplitter(mTopWidget);
     connect(mSplitter, &QSplitter::splitterMoved, this, &MainWindow::slotSplitterMoved);
     layout->addWidget(mSplitter);
@@ -281,7 +314,7 @@ void MainWindow::initAboutScreen()
 
 void MainWindow::setupActions()
 {
-    actionCollection()->addAction(KStandardAction::Quit, this, SLOT(slotQuit()));
+    KStandardAction::quit(this, &MainWindow::slotQuit, actionCollection());
 
     mNewActions = new KActionMenu(i18nc("@title:menu create new pim items (message,calendar,to-do,etc.)", "New"), this);
     actionCollection()->addAction(QStringLiteral("action_new"), mNewActions);
